# A rule for debian packages to check that all files installed by the
# build are actually packaged.  To use it, place it in e.g. your debian/
# directory and add the following line to debian/rules:
#
#  include debian/checkmissing.mk
#
# This file is derived from utils.mk from cdbs.

check-missing-files:
	@if test -d debian/tmp; then \
	  (cd debian/tmp && find . -type f -o -type l | grep -v '/DEBIAN/' \
             | sed -e 's/.gz$$//' | sort) > debian/cdbs-install-list; \
	  if [ -z "$(DEB_ALL_PACKAGES)" ]; then \
	    packages=$$(sed -n -e 's/Package: *//p' debian/control); \
	  else \
	    packages="$(DEB_ALL_PACKAGES)"; \
	  fi; \
	  echo "looking for missing files in $$packages"; \
	  (for package in $$packages; do \
	     (cd debian/$$package && find . -type f -o -type l); \
	   done) | sed -e 's/.gz$$//' | sort -u > debian/cdbs-package-list; \
	  diff --new-group-format="" --unchanged-group-format="" \
               debian/cdbs-install-list debian/cdbs-package-list > debian/cdbs-unpackaged; \
	  if [ -s debian/cdbs-unpackaged ]; then \
	    echo "---- the following files were installed but not packaged:"; \
	    cat debian/cdbs-unpackaged; \
	    exit 1; \
	  else \
	    echo "all files were packaged"; \
	  fi \
	else \
	  echo "All files were installed into debian/$(DEB_SOURCE_PACKAGE)."; \
	fi


# run
.PHONY: check-missing-files
